@@ -6,12 +6,22 @@ from plone.app.testing import IntegrationTesting
 from plone.app.testing import PLONE_FIXTURE
 from plone.app.testing import PloneSandboxLayer
 from plone.registry.interfaces import IRegistry
-from plone.testing import z2
 from zope.component import getUtility
 from zope.interface import alsoProvides
 
 import os
 
+try:
+    # plone.testing 7+, Plone 5.2+
+    from plone.testing.zope import WSGI_SERVER_FIXTURE
+    from plone.testing.zope import installProduct
+    from plone.testing.zope import uninstallProduct
+except ImportError:
+    # plone.testing 6-, Plone 5.1
+    from plone.testing.z2 import ZSERVER_FIXTURE as WSGI_SERVER_FIXTURE
+    from plone.testing.z2 import installProduct
+    from plone.testing.z2 import uninstallProduct
+
 
 def set_browserlayer(request):
     """Set the BrowserLayer for the request.
@@ -69,7 +79,7 @@ class PAEventLayer(PloneSandboxLayer):
         self.ostz = os_zone()
 
         # Install products that use an old-style initialize() function
-        z2.installProduct(app, 'Products.DateRecurringIndex')
+        installProduct(app, 'Products.DateRecurringIndex')
 
         # Load ZCML
         import plone.app.event
@@ -81,7 +91,7 @@ class PAEventLayer(PloneSandboxLayer):
 
     def tearDownZope(self, app):
         # Uninstall old-style Products
-        z2.uninstallProduct(app, 'Products.DateRecurringIndex')
+        uninstallProduct(app, 'Products.DateRecurringIndex')
 
         # reset OS TZ
         if self.ostz:
@@ -129,6 +139,6 @@ PAEventDX_ROBOT_TESTING = FunctionalTesting(
     bases=(
         PAEventDX_FIXTURE,
         AUTOLOGIN_LIBRARY_FIXTURE,
-        z2.ZSERVER_FIXTURE,
+        WSGI_SERVER_FIXTURE,
     ),
     name="plone.app.event.dx:Robot")
